@@ -16,13 +16,8 @@ from gensim.models.doc2vec import Doc2Vec, TaggedDocument
 from gensim.utils import tokenize
 
 import traceback
-import csv
+import utils
 import pickle
-from sklearn.feature_extraction.text import CountVectorizer, TfidfTransformer
-
-def loadcsv(filename):
-    with open(filename, newline='') as f: 
-        return list(csv.reader(f))
 
 model = None
 ld = None
@@ -99,6 +94,10 @@ def getfeatures(txt):
 
     return features
 
+def free():
+    global doc2vec_model
+    del doc2vec_model
+
 if __name__ == "__main__":
     while True:
         txt = input("Enter text: ")
